@@ -1,10 +1,16 @@
-AUTO_GEN_QUEUE_NAME = ""
+"""
+Exchange properties
+"""
 
-DEFAULT_EXCHANGE = ""
 
 EXCHANGE_TYPE_FANOUT = "fanout"
 
 
+"""
+Generic class info
+"""
+
+
 class Printable:
     """
     Makes the print format like I want it :-).
